@@ -50,7 +50,7 @@ class ANOVAFunction(Benchmark):
         self.a = rng.random((6,3)) * 10
         self.b = rng.random((6,3)) * 10
         self.c = rng.random((6,3)) * 10
-    
+
     def time_f_oneway(self):
         statistic, pvalue = stats.f_oneway(self.a, self.b, self.c)
         statistic, pvalue = stats.f_oneway(self.a, self.b, self.c, axis=1)
@@ -74,15 +74,70 @@ class Kendalltau(Benchmark):
         self.b = b
 
     def time_kendalltau(self, nan_policy, method, variant):
-        tau, p_value = stats.kendalltau(self.a, self.b, nan_policy=nan_policy, method=method, variant=variant)
+        stats.kendalltau(self.a, self.b, nan_policy=nan_policy,
+                         method=method, variant=variant)
+
+
+class KS(Benchmark):
+    param_names = ['alternative', 'mode']
+    params = [
+        ['two-sided', 'less', 'greater'],
+        ['auto', 'exact', 'asymp'],
+    ]
+
+    def setup(self, alternative, mode):
+        rng = np.random.default_rng(0x2e7c964ff9a5cd6be22014c09f1dbba9)
+        self.a = stats.norm.rvs(loc=5, scale=10, size=500, random_state=rng)
+        self.b = stats.norm.rvs(loc=8, scale=10, size=500, random_state=rng)
+
+    def time_ks_1samp(self, alternative, mode):
+        stats.ks_1samp(self.a, stats.norm.cdf,
+                       alternative=alternative, mode=mode)
+
+    def time_ks_2samp(self, alternative, mode):
+        stats.ks_2samp(self.a, self.b, alternative=alternative, mode=mode)
+
+
+class RankSums(Benchmark):
+    param_names = ['alternative']
+    params = [
+        ['two-sided', 'less', 'greater']
+    ]
+
+    def setup(self, alternative):
+        rng = np.random.default_rng(0xb6acd7192d6e5da0f68b5d8ab8ce7af2)
+        self.u1 = rng.uniform(-1, 1, 200)
+        self.u2 = rng.uniform(-0.5, 1.5, 300)
+
+    def time_ranksums(self, alternative):
+        stats.ranksums(self.u1, self.u2, alternative=alternative)
+
+
+class BrunnerMunzel(Benchmark):
+    param_names = ['alternative', 'nan_policy', 'distribution']
+    params = [
+        ['two-sided', 'less', 'greater'],
+        ['propagate', 'raise', 'omit'],
+        ['t', 'normal']
+    ]
+
+    def setup(self, alternative, nan_policy, distribution):
+        rng = np.random.default_rng(0xb82c4db22b2818bdbc5dbe15ad7528fe)
+        self.u1 = rng.uniform(-1, 1, 200)
+        self.u2 = rng.uniform(-0.5, 1.5, 300)
+
+    def time_brunnermunzel(self, alternative, nan_policy, distribution):
+        stats.brunnermunzel(self.u1, self.u2, alternative=alternative,
+                            distribution=distribution, nan_policy=nan_policy)
 
 
 class InferentialStats(Benchmark):
     def setup(self):
-        np.random.seed(12345678)
-        self.a = stats.norm.rvs(loc=5, scale=10, size=500)
-        self.b = stats.norm.rvs(loc=8, scale=10, size=20)
-        self.c = stats.norm.rvs(loc=8, scale=20, size=20)
+        rng = np.random.default_rng(0x13d756fadb635ae7f5a8d39bbfb0c931)
+        self.a = stats.norm.rvs(loc=5, scale=10, size=500, random_state=rng)
+        self.b = stats.norm.rvs(loc=8, scale=10, size=500, random_state=rng)
+        self.c = stats.norm.rvs(loc=8, scale=20, size=500, random_state=rng)
+        self.chisq = rng.integers(1, 20, 500)
 
     def time_ttest_ind_same_var(self):
         # test different sized sample with variances
@@ -94,6 +149,45 @@ class InferentialStats(Benchmark):
         stats.ttest_ind(self.a, self.c)
         stats.ttest_ind(self.a, self.c, equal_var=False)
 
+    def time_chisqure(self):
+        stats.chisquare(self.chisq)
+
+    def time_friedmanchisquare(self):
+        stats.friedmanchisquare(self.a, self.b, self.c)
+
+    def time_epps_singleton_2samp(self):
+        stats.epps_singleton_2samp(self.a, self.b)
+
+    def time_kruskal(self):
+        stats.mstats.kruskal(self.a, self.b)
+
+
+# Benchmark data for the truncnorm stats() method.
+# The data in each row is:
+#   a, b, mean, variance, skewness, excess kurtosis. Generated using
+# https://gist.github.com/WarrenWeckesser/636b537ee889679227d53543d333a720
+truncnorm_cases = [[-20, -19, -19.052343945976656, 0.002725073018195613,
+                   -1.9838693623377885, 5.871801893091683],
+                   [-30, -29, -29.034401237736176, 0.0011806604886186853,
+                    -1.9929615171469608, 5.943905539773037],
+                   [-40, -39, -39.02560741993011, 0.0006548827702932775,
+                    -1.9960847672775606, 5.968744357649675],
+                   [39, 40, 39.02560741993011, 0.0006548827702932775,
+                    1.9960847672775606, 5.968744357649675]]
+truncnorm_cases = np.array(truncnorm_cases)
+
+
+class TruncnormStats(Benchmark):
+    param_names = ['case', 'moment']
+    params = [list(range(len(truncnorm_cases))), ['m', 'v', 's', 'k']]
+
+    def track_truncnorm_stats_error(self, case, moment):
+        result_indices = dict(zip(['m', 'v', 's', 'k'], range(2, 6)))
+        ref = truncnorm_cases[case, result_indices[moment]]
+        a, b = truncnorm_cases[case, 0:2]
+        res = stats.truncnorm(a, b).stats(moments=moment)
+        return np.abs((res - ref)/ref)
+
 
 class DistributionsAll(Benchmark):
     # all distributions are in this list. A conversion to a set is used to
@@ -182,6 +276,95 @@ class DistributionsAll(Benchmark):
         self.method(*self.args, **self.kwds)
 
 
+class TrackContinuousRoundtrip(Benchmark):
+    # Benchmarks that track a value for every distribution can go here
+    param_names = ['dist_name']
+    params = list(dict(distcont).keys())
+    dist_data = dict(distcont)
+
+    def setup(self, dist_name):
+        # Distribution setup follows `DistributionsAll` benchmark.
+        # This focuses on ppf, so the code for handling other functions is
+        # removed for simplicity.
+        self.dist = getattr(stats, dist_name)
+        self.shape_args = self.dist_data[dist_name]
+
+    def track_distribution_ppf_roundtrip(self, dist_name):
+        # Tracks the worst relative error of a
+        # couple of round-trip ppf -> cdf calculations.
+        vals = [0.001, 0.5, 0.999]
+
+        ppf = self.dist.ppf(vals, *self.shape_args)
+        round_trip = self.dist.cdf(ppf, *self.shape_args)
+
+        err_rel = np.abs(vals - round_trip) / vals
+        return np.max(err_rel)
+
+    def track_distribution_ppf_roundtrip_extrema(self, dist_name):
+        # Tracks the absolute error of an "extreme" round-trip
+        # ppf -> cdf calculation.
+        v = 1e-6
+        ppf = self.dist.ppf(v, *self.shape_args)
+        round_trip = self.dist.cdf(ppf, *self.shape_args)
+
+        err_abs = np.abs(v - round_trip)
+        return err_abs
+
+    def track_distribution_isf_roundtrip(self, dist_name):
+        # Tracks the worst relative error of a
+        # couple of round-trip isf -> sf calculations.
+        vals = [0.001, 0.5, 0.999]
+
+        isf = self.dist.isf(vals, *self.shape_args)
+        round_trip = self.dist.sf(isf, *self.shape_args)
+
+        err_rel = np.abs(vals - round_trip) / vals
+        return np.max(err_rel)
+
+    def track_distribution_isf_roundtrip_extrema(self, dist_name):
+        # Tracks the absolute error of an "extreme" round-trip
+        # isf -> sf calculation.
+        v = 1e-6
+        ppf = self.dist.isf(v, *self.shape_args)
+        round_trip = self.dist.sf(ppf, *self.shape_args)
+
+        err_abs = np.abs(v - round_trip)
+        return err_abs
+
+
+class PDFPeakMemory(Benchmark):
+    # Tracks peak memory when a distribution is given a large array to process
+    # See gh-14095
+
+    # Run for up to 30 min - some dists are quite slow.
+    timeout = 1800.0
+
+    x = np.arange(1e6)
+
+    param_names = ['dist_name']
+    params = list(dict(distcont).keys())
+    dist_data = dict(distcont)
+
+    # So slow that 30min isn't enough time to finish.
+    slow_dists = ["levy_stable"]
+
+    def setup(self, dist_name):
+        # This benchmark is demanding. Skip it if the env isn't xslow.
+        if not is_xslow():
+            raise NotImplementedError("skipped - enviroment is not xslow. "
+                                      "To enable this benchamark, set the "
+                                      "enviroment variable SCIPY_XSLOW=1")
+
+        if dist_name in self.slow_dists:
+            raise NotImplementedError("skipped - dist is too slow.")
+
+        self.dist = getattr(stats, dist_name)
+        self.shape_args = self.dist_data[dist_name]
+
+    def peakmem_bigarr_pdf(self, dist_name):
+        self.dist.pdf(self.x, *self.shape_args)
+
+
 class Distribution(Benchmark):
     # though there is a new version of this benchmark that runs all the
     # distributions, at the time of writing there was odd behavior on
@@ -195,8 +378,8 @@ class Distribution(Benchmark):
     ]
 
     def setup(self, distribution, properties):
-        np.random.seed(12345678)
-        self.x = np.random.rand(100)
+        rng = np.random.default_rng(12345678)
+        self.x = rng.random(100)
 
     def time_distribution(self, distribution, properties):
         if distribution == 'gamma':
@@ -238,8 +421,8 @@ class DescriptiveStats(Benchmark):
     ]
 
     def setup(self, n_levels):
-        np.random.seed(12345678)
-        self.levels = np.random.randint(n_levels, size=(1000, 10))
+        rng = np.random.default_rng(12345678)
+        self.levels = rng.integers(n_levels, size=(1000, 10))
 
     def time_mode(self, n_levels):
         stats.mode(self.levels, axis=0)
@@ -247,10 +430,10 @@ class DescriptiveStats(Benchmark):
 
 class GaussianKDE(Benchmark):
     def setup(self):
-        np.random.seed(12345678)
+        rng = np.random.default_rng(12345678)
         n = 2000
-        m1 = np.random.normal(size=n)
-        m2 = np.random.normal(scale=0.5, size=n)
+        m1 = rng.normal(size=n)
+        m2 = rng.normal(scale=0.5, size=n)
 
         xmin = m1.min()
         xmax = m1.max()
@@ -276,16 +459,16 @@ class GroupSampling(Benchmark):
     params = [[3, 10, 50, 200]]
 
     def setup(self, dim):
-        np.random.seed(12345678)
+        self.rng = np.random.default_rng(12345678)
 
     def time_unitary_group(self, dim):
-        stats.unitary_group.rvs(dim)
+        stats.unitary_group.rvs(dim, random_state=self.rng)
 
     def time_ortho_group(self, dim):
-        stats.ortho_group.rvs(dim)
+        stats.ortho_group.rvs(dim, random_state=self.rng)
 
     def time_special_ortho_group(self, dim):
-        stats.special_ortho_group.rvs(dim)
+        stats.special_ortho_group.rvs(dim, random_state=self.rng)
 
 
 class BinnedStatisticDD(Benchmark):
@@ -293,8 +476,8 @@ class BinnedStatisticDD(Benchmark):
     params = ["count", "sum", "mean", "min", "max", "median", "std", np.std]
 
     def setup(self, statistic):
-        np.random.seed(12345678)
-        self.inp = np.random.rand(9999).reshape(3, 3333) * 200
+        rng = np.random.default_rng(12345678)
+        self.inp = rng.random(9999).reshape(3, 3333) * 200
         self.subbin_x_edges = np.arange(0, 200, dtype=np.float32)
         self.subbin_y_edges = np.arange(0, 200, dtype=np.float64)
         self.ret = stats.binned_statistic_dd(
@@ -402,35 +585,82 @@ class BenchQMCDiscrepancy(Benchmark):
     ]
 
     def setup(self, method):
-        np.random.seed(1234)
-        sample = np.random.random_sample((1000, 10))
+        rng = np.random.default_rng(1234)
+        sample = rng.random((1000, 10))
         self.sample = sample
 
     def time_discrepancy(self, method):
         disc = stats.qmc.discrepancy(self.sample, method=method)
 
 
-class NumericalInverseHermite(Benchmark):
+class BenchQMCHalton(Benchmark):
+    param_names = ['d', 'scramble', 'n', 'workers']
+    params = [
+        [1, 10],
+        [True, False],
+        [10, 1_000, 100_000],
+        [1, 4]
+    ]
 
-    param_names = ['distribution']
-    params = [distcont]
+    def setup(self, d, scramble, n, workers):
+        self.rng = np.random.default_rng(1234)
 
-    def setup(self, *args):
-        self.rand = [np.random.normal(loc=i, size=1000) for i in range(3)]
+    def time_halton(self, d, scramble, n, workers):
+        seq = stats.qmc.Halton(d, scramble=scramble, seed=self.rng)
+        seq.random(n, workers=workers)
 
-    def time_fni(self, distcase):
-        distname, shapes = distcase
-        slow_dists = {'ksone', 'kstwo', 'levy_stable', 'skewnorm'}
-        fail_dists = {'beta', 'gausshyper', 'geninvgauss', 'ncf', 'nct',
-                      'norminvgauss', 'genhyperbolic', 'studentized_range'}
 
-        if distname in slow_dists or distname in fail_dists:
-            raise NotImplementedError("skipped")
+class BenchQMCSobol(Benchmark):
+    param_names = ['d', 'base2']
+    params = [
+        [1, 50, 100],
+        [3, 10, 11, 12],
+    ]
 
-        dist = getattr(stats, distname)(*shapes)
+    def setup(self, d, base2):
+        self.rng = np.random.default_rng(168525179735951991038384544)
+        stats.qmc.Sobol(1, bits=32)  # make it load direction numbers
 
-        with np.testing.suppress_warnings() as sup:
-            sup.filter(RuntimeWarning, "overflow encountered")
-            sup.filter(RuntimeWarning, "divide by zero")
-            sup.filter(RuntimeWarning, "invalid value encountered")
-            stats.NumericalInverseHermite(dist)
+    def time_sobol(self, d, base2):
+        # scrambling is happening at init only, not worth checking
+        seq = stats.qmc.Sobol(d, scramble=False, bits=32, seed=self.rng)
+        seq.random_base2(base2)
+
+
+class DistanceFunctions(Benchmark):
+    param_names = ['n_size']
+    params = [
+        [10, 4000]
+    ]
+
+    def setup(self, n_size):
+        rng = np.random.default_rng(12345678)
+        self.u_values = rng.random(n_size) * 10
+        self.u_weights = rng.random(n_size) * 10
+        self.v_values = rng.random(n_size // 2) * 10
+        self.v_weights = rng.random(n_size // 2) * 10
+
+    def time_energy_distance(self, n_size):
+        distance = stats.energy_distance(
+                 self.u_values, self.v_values,
+                 self.u_weights, self.v_weights)
+
+    def time_wasserstein_distance(self, n_size):
+        distance = stats.wasserstein_distance(
+                 self.u_values, self.v_values,
+                 self.u_weights, self.v_weights)
+
+
+class Somersd(Benchmark):
+    param_names = ['n_size']
+    params = [
+        [10, 100]
+    ]
+
+    def setup(self, n_size):
+        rng = np.random.default_rng(12345678)
+        self.x = rng.choice(n_size, size=n_size)
+        self.y = rng.choice(n_size, size=n_size)
+
+    def time_somersd(self, n_size):
+        res = stats.somersd(self.x, self.y)
