@@ -33,7 +33,6 @@ inspect.isdescriptor = (lambda obj: old_isdesc(obj)
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 
-sys.path.insert(0, os.path.abspath('../sphinxext'))
 sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
 
 import numpydoc.docscrape as np_docscrape  # noqa:E402
@@ -49,6 +48,7 @@ extensions = [
     'scipyoptdoc',
     'doi_role',
     'matplotlib.sphinxext.plot_directive',
+    'sphinx_tabs.tabs',
 ]
 
 # Determine if the matplotlib has a recent enough version of the
@@ -73,7 +73,7 @@ templates_path = ['_templates']
 # The suffix of source filenames.
 source_suffix = '.rst'
 
-# The master toctree document.
+# The main toctree document.
 master_doc = 'index'
 
 # General substitutions.
@@ -86,6 +86,11 @@ import scipy
 version = re.sub(r'\.dev-.*$', r'.dev', scipy.__version__)
 release = scipy.__version__
 
+if os.environ.get('CIRCLE_JOB', False) and \
+        os.environ.get('CIRCLE_BRANCH', '') != 'main':
+    version = os.environ['CIRCLE_BRANCH']
+    release = version
+
 print("%s (VERSION %s)" % (project, version))
 
 # There are two options for replacing |today|: either, you set today to some
@@ -147,10 +152,8 @@ warnings.filterwarnings('error')
 warnings.filterwarnings('default', module='sphinx')  # internal warnings
 # global weird ones that can be safely ignored
 for key in (
-        r"'U' mode is deprecated",  # sphinx io
         r"OpenSSL\.rand is deprecated",  # OpenSSL package in linkcheck
-        r"Using or importing the ABCs from",  # 3.5 importlib._bootstrap
-        r"'contextfunction' is renamed to 'pass_context'",  # Jinja
+        r"distutils Version",  # distutils
         ):
     warnings.filterwarnings(  # deal with other modules having bad imports
         'ignore', message=".*" + key, category=DeprecationWarning)
@@ -182,27 +185,29 @@ html_logo = '_static/logo.svg'
 html_favicon = '_static/favicon.ico'
 
 html_theme_options = {
-  "logo_link": "index",
   "github_url": "https://github.com/scipy/scipy",
-  "navbar_start": ["navbar-logo", "version"],
+  "twitter_url": "https://twitter.com/SciPy_team",
+  "navbar_end": ["theme-switcher", "version-switcher", "navbar-icon-links"],
+  "switcher": {
+      "json_url": "https://scipy.github.io/devdocs/_static/version_switcher.json",
+      "version_match": version,
+  }
 }
 
+if 'dev' in version:
+    html_theme_options["switcher"]["version_match"] = "dev"
+
 if 'versionwarning' in tags:
     # Specific to docs.scipy.org deployment.
-    # See https://github.com/scipy/docs.scipy.org/blob/master/_static/versionwarning.js_t
+    # See https://github.com/scipy/docs.scipy.org/blob/main/_static/versionwarning.js_t
     src = ('var script = document.createElement("script");\n'
            'script.type = "text/javascript";\n'
            'script.src = "/doc/_static/versionwarning.js";\n'
            'document.head.appendChild(script);');
     html_context = {
-        'VERSIONCHECK_JS': src,
-        'versionwarning': True
+        'VERSIONCHECK_JS': src
     }
     html_js_files = ['versioncheck.js']
-else:
-    html_context = {
-        'versionwarning': False
-    }
 
 html_title = "%s v%s Manual" % (project, version)
 html_static_path = ['_static']
@@ -225,129 +230,14 @@ htmlhelp_basename = 'scipy'
 
 mathjax_path = "scipy-mathjax/MathJax.js?config=scipy-mathjax"
 
-
-# -----------------------------------------------------------------------------
-# LaTeX output
-# -----------------------------------------------------------------------------
-
-# Grouping the document tree into LaTeX files. List of tuples
-# (source start file, target name, title, author, document class [howto/manual]).
-_stdauthor = 'Written by the SciPy community'
-latex_documents = [
-  ('index', 'scipy-ref.tex', 'SciPy Reference Guide', _stdauthor, 'manual'),
-#  ('user/index', 'scipy-user.tex', 'SciPy User Guide',
-#   _stdauthor, 'manual'),
-]
-
-# Not available on many systems:
-latex_use_xindy = False
-
-# The name of an image file (relative to this directory) to place at the top of
-# the title page.
-#latex_logo = None
-
-# Documents to append as an appendix to all manuals.
-#latex_appendices = []
-
-# If false, no module index is generated.
-latex_domain_indices = False
-
-# fix issues with Unicode characters
-latex_engine = 'xelatex'
-
-latex_elements = {
-    # The paper size ('letterpaper' or 'a4paper').
-    #
-    # 'papersize': 'letterpaper',
-
-    # The font size ('10pt', '11pt' or '12pt').
-    #
-    # 'pointsize': '10pt',
-
-    # Additional stuff for the LaTeX preamble.
-    #
-    'preamble': r'''
-% In the parameters etc. sections, align uniformly, and adjust label emphasis
-\usepackage{expdlist}
-\let\latexdescription=\description
-\let\endlatexdescription=\enddescription
-\renewenvironment{description}
-{\renewenvironment{description}
-   {\begin{latexdescription}%
-    [\setleftmargin{50pt}\breaklabel\setlabelstyle{\bfseries}]%
-   }%
-   {\end{latexdescription}}%
- \begin{latexdescription}%
-    [\setleftmargin{15pt}\breaklabel\setlabelstyle{\bfseries\itshape}]%
-}%
-{\end{latexdescription}}
-% Fix bug in expdlist's modified \@item
-\usepackage{etoolbox}
-\makeatletter
-\patchcmd\@item{{\@breaklabel} }{{\@breaklabel}}{}{}
-% Fix bug in expdlist's way of breaking the line after long item label
-\def\breaklabel{%
-    \def\@breaklabel{%
-        \leavevmode\par
-        % now a hack because Sphinx inserts \leavevmode after term node
-        \def\leavevmode{\def\leavevmode{\unhbox\voidb@x}}%
-    }%
-}
-\makeatother
-
-% Make Examples/etc section headers smaller and more compact
-\titlespacing*{\paragraph}{0pt}{1ex}{0pt}
-
-% Save vertical space in parameter lists and elsewhere
-\makeatletter
-\renewenvironment{quote}%
-               {\list{}{\topsep=0pt\relax
-                        \parsep \z@ \@plus\p@}%
-                \item\relax}%
-               {\endlist}
-\makeatother
-% Avoid small font size in code-blocks
-\fvset{fontsize=auto}
-% Use left-alignment per default in tabulary rendered tables
-\newcolumntype{T}{L}
-% Get some useful deeper bookmarks and table of contents in PDF
-\setcounter{tocdepth}{1}
-% Fix: ≠ is unknown to XeLaTeX's default font Latin Modern
-\usepackage{newunicodechar}
-\newunicodechar{≠}{\ensuremath{\neq}}
-% Get PDF to use maximal depth bookmarks
-\hypersetup{bookmarksdepth=subparagraph}
-% reduce hyperref warnings
-\pdfstringdefDisableCommands{%
-  \let\sphinxupquote\empty
-  \let\sphinxstyleliteralintitle\empty
-  \let\sphinxstyleemphasis\empty
-}
-''',
-    # Latex figure (float) alignment
-    #
-    # 'figure_align': 'htbp',
-
-    # benefit from  Sphinx built-in workaround of LaTeX's list limitations
-    'maxlistdepth': '12',
-
-    # reduce TeX warnings about underfull boxes in the index
-    'printindex': r'\raggedright\printindex',
-
-    # avoid potential problems arising from erroneous mark-up of the
-    # \mathbf{\Gamma} type
-    'passoptionstopackages': r'\PassOptionsToPackage{no-math}{fontspec}',
-}
-
-
 # -----------------------------------------------------------------------------
 # Intersphinx configuration
 # -----------------------------------------------------------------------------
 intersphinx_mapping = {
-    'python': ('https://docs.python.org/dev', None),
+    'python': ('https://docs.python.org/3', None),
     'numpy': ('https://numpy.org/devdocs', None),
     'neps': ('https://numpy.org/neps', None),
-    'matplotlib': ('https://matplotlib.org', None),
+    'matplotlib': ('https://matplotlib.org/stable', None),
     'asv': ('https://asv.readthedocs.io/en/stable/', None),
 }
 
@@ -408,7 +298,7 @@ import numpy as np
 np.random.seed(123)
 """
 plot_include_source = True
-plot_formats = [('png', 96), 'pdf']
+plot_formats = [('png', 96)]
 plot_html_show_formats = False
 plot_html_show_source_link = False
 
@@ -509,7 +399,7 @@ def linkcode_resolve(domain, info):
             return "https://github.com/scipy/scipy/blob/%s/%s%s" % (
                 m.group(1), fn, linespec)
         elif 'dev' in scipy.__version__:
-            return "https://github.com/scipy/scipy/blob/master/%s%s" % (
+            return "https://github.com/scipy/scipy/blob/main/%s%s" % (
                 fn, linespec)
         else:
             return "https://github.com/scipy/scipy/blob/v%s/%s%s" % (
