@@ -67,10 +67,7 @@ import shutil
 import subprocess
 import time
 import datetime
-try:
-    from types import ModuleType as new_module
-except ImportError:  # old Python
-    from imp import new_module
+from types import ModuleType as new_module  # noqa: E402
 
 ROOT_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__)))
 
@@ -141,7 +138,7 @@ def main(argv):
     if args.pep8:
         # Lint the source using the configuration in tox.ini.
         os.system("flake8 scipy benchmarks/benchmarks")
-        # Lint just the diff since branching off of master using a
+        # Lint just the diff since branching off of main using a
         # stricter configuration.
         lint_diff = os.path.join(ROOT_DIR, 'tools', 'lint_diff.py')
         os.system(lint_diff)
@@ -226,6 +223,8 @@ def main(argv):
     if args.refguide_check:
         cmd = [os.path.join(ROOT_DIR, 'tools', 'refguide_check.py'),
                '--doctests']
+        if args.verbose:
+            cmd += ['-' + 'v'*args.verbose]
         if args.submodule:
             cmd += [args.submodule]
         os.execv(sys.executable, [sys.executable] + cmd)
@@ -290,8 +289,22 @@ def main(argv):
     if args.build_only:
         sys.exit(0)
     else:
-        __import__(PROJECT_MODULE)
-        test = sys.modules[PROJECT_MODULE].test
+        try:
+            test, version, mod_path = import_module()
+        except ImportError:
+            # this may fail when running with --no-build, so try to detect
+            # an installed scipy in a subdir inside a repo
+            dst_dir = os.path.join(ROOT_DIR, 'build', 'testenv')
+            from sysconfig import get_path
+            py_path = get_path('platlib')
+            site_dir = os.path.join(dst_dir, get_path_suffix(py_path, 3))
+            print("Trying to import scipy from development installed path at:",
+                  site_dir)
+            sys.path.insert(0, site_dir)
+            os.environ['PYTHONPATH'] = \
+                os.pathsep.join((site_dir, os.environ.get('PYTHONPATH', '')))
+            test, version, mod_path = import_module()
+
 
     if args.submodule:
         tests = [PROJECT_MODULE + "." + args.submodule]
@@ -315,6 +328,8 @@ def main(argv):
     cwd = os.getcwd()
     try:
         os.chdir(test_dir)
+        print("Running tests for {} version:{}, installed at:{}".format(
+              PROJECT_MODULE, version, mod_path))
         result = test(args.mode,
                       verbose=args.verbose,
                       extra_argv=extra_argv,
@@ -333,6 +348,33 @@ def main(argv):
         sys.exit(1)
 
 
+def import_module():
+    """
+    Function of import project module.
+    """
+    __import__(PROJECT_MODULE)
+    test = sys.modules[PROJECT_MODULE].test
+    version = sys.modules[PROJECT_MODULE].__version__
+    mod_path = sys.modules[PROJECT_MODULE].__file__
+    mod_path = os.path.abspath(os.path.join(os.path.dirname(mod_path)))
+    return test, version, mod_path
+
+
+def get_path_suffix(current_path, levels=3):
+    """
+    This utility function is only needed for a single use further down,
+    in order to grab the last `levels` subdirs from the input path.
+    It'll always resolve to something like ``lib/python3.X/site-packages``.
+    Site-packages is actually 3 levels deep on all platforms, so this
+    function should suffice.
+    """
+    current_new = current_path
+    for i in range(levels):
+        current_new = os.path.dirname(current_new)
+
+    return os.path.relpath(current_path, current_new)
+
+
 def build_project(args):
     """
     Build a dev version of the project.
@@ -365,8 +407,8 @@ def build_project(args):
         env['OPT'] = '-O0 -ggdb'
         env['FOPT'] = '-O0 -ggdb'
         if args.gcov:
-            import distutils.sysconfig
-            cvars = distutils.sysconfig.get_config_vars()
+            from sysconfig import get_config_vars
+            cvars = get_config_vars()
             env['OPT'] = '-O0 -ggdb'
             env['FOPT'] = '-O0 -ggdb'
             env['CC'] = env.get('CC', cvars['CC']) + ' --coverage'
@@ -385,8 +427,10 @@ def build_project(args):
             '--single-version-externally-managed',
             '--record=' + dst_dir + 'tmp_install_log.txt']
 
-    from distutils.sysconfig import get_python_lib
-    site_dir = get_python_lib(prefix=dst_dir, plat_specific=True)
+    from sysconfig import get_path
+    py_path = get_path('platlib')
+    site_dir = os.path.join(dst_dir, get_path_suffix(py_path, 3))
+
     # easy_install won't install to a path that Python by default cannot see
     # and isn't on the PYTHONPATH. Plus, it has to exist.
     if not os.path.exists(site_dir):
